@@ -26,7 +26,7 @@ PLMF = MessageFactory('plonelocales')
 ATMF = MessageFactory('atcontenttypes')
 DTMF = MessageFactory('collective.z3cform.datetimewidget')
 from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
-from Solgema.fullcalendar.interfaces import ISolgemaFullcalendarView, ISolgemaFullcalendarEvents, ISolgemaFullcalendarProperties, ISFBaseEventFields
+from Solgema.fullcalendar.interfaces import *
 from Solgema.fullcalendar.browser.solgemafullcalendar_views import getTopic, getCriteriaItems, getColorIndex
 
 # Check for Plone versions
@@ -55,38 +55,7 @@ def getCopyObjectsUID(REQUEST):
 class SFJsonEvent(BrowserView):
 
     def __call__(self, *args, **kw):
-        copyDict = getCopyObjectsUID(self.request)
-        catalog = getToolByName(self.context, 'portal_catalog')
-        event = self.context
-        eventPhysicalPath = '/'.join(event.getPhysicalPath())
-        wft = getToolByName(event, 'portal_workflow')
-        state = wft.getInfoFor(event, 'review_state')
-        member = self.context.portal_membership.getAuthenticatedMember()
-        memberid = member.id
-        if member.has_permission('Modify portal content', event):
-            editable = True
-        if event.end() - event.start() > 1.0:
-            allday = True
-        else:
-            allday = False
-        adapted = ISFBaseEventFields(event, None)
-        if adapted:
-            allday = adapted.allDay
-        copycut = ''
-        if copyDict and eventPhysicalPath == copyDict['url']:
-            copycut = copyDict['op'] == 1 and ' event_cutted' or ' event_copied'
-        typeClass = ' type-'+event.portal_type
-        colorIndex = getColorIndex(self.context, self.request, eventPhysicalPath)
-        eventDict = {"status": "ok",
-                     "id": "UID_%s" % (event.UID()), 
-                     "title": event.Title(),
-                     "description": event.Description(),
-                     "start": event.start().rfc822(),
-                     "end": event.end().rfc822(),
-                     "url": event.absolute_url(),
-                     "editable": editable,
-                     "allDay": allday, 
-                     "className": "contextualContentMenuEnabled state-" + str(state) + (editable and " editable" or "")+copycut+typeClass+colorIndex}
+        eventDict = getMultiAdapter((self.context, self.request), ISolgemaFullcalendarEventDict)()
         return json.dumps(eventDict, sort_keys=True)
 
 class SFDisplayAddMenu(BrowserView):
@@ -310,28 +279,7 @@ class SFJsonEventPaste(BrowserView):
         self.copyDict = getCopyObjectsUID(self.request)
 
     def createJsonEvent(self, event):
-        editable = True
-        eventPhysicalPath = '/'.join(event.getPhysicalPath())
-        wft = getToolByName(event, 'portal_workflow')
-        state = wft.getInfoFor(event, 'review_state')
-        if event.end() - event.start() > 1.0:
-            allday = True
-        else:
-            allday = False
-        copycut = ''
-        if self.copyDict and eventPhysicalPath == self.copyDict['url']:
-            copycut = self.copyDict['op'] == 1 and ' event_cutted' or ' event_copied'
-        typeClass = ' type-'+event.portal_type
-        colorIndex = getColorIndex(self.context, self.request, eventPhysicalPath)
-        return {"id": "UID_%s" % (event.UID()), 
-                "title": event.Title(), 
-                "description": event.Description(),
-                "start": event.start().rfc822(),
-                "end": event.end().rfc822(),
-                "url": event.absolute_url(),
-                "editable": editable,
-                "allDay": allday, 
-                "className": "contextualContentMenuEnabled state-" + str(state) + (editable and " editable" or "")+copycut+typeClass+colorIndex}
+        return getMultiAdapter((event, self.request), ISolgemaFullcalendarEventDict)()
 
     def __call__(self):
         
@@ -428,27 +376,7 @@ class SolgemaFullcalendarWorkflowTransition(BrowserView):
 
         transaction_note(note)
 
-        editable = True
-        wft = getToolByName(event, 'portal_workflow')
-        state = wft.getInfoFor(event, 'review_state')
-        if event.end() - event.start() > 1.0:
-            allday = True
-        else:
-            allday = False
-        copycut = ''
-        if copyDict and eventPhysicalPath == copyDict['url']:
-            copycut = copyDict['op'] == 1 and ' event_cutted' or ' event_copied'
-        typeClass = ' type-'+event.portal_type
-        colorIndex = getColorIndex(self.context, self.request, eventPhysicalPath)
-        eventDict = {"id": "UID_%s" % (event.UID()), 
-                     "title": event.Title(), 
-                     "description": event.Description(),
-                     "start": event.start().rfc822(),
-                     "end": event.end().rfc822(),
-                     "url": event.absolute_url(),
-                     "editable": editable,
-                     "allDay": allday, 
-                     "className": "contextualContentMenuEnabled state-" + str(state) + (editable and " editable" or "")+copycut+typeClass+colorIndex}
+        eventDict = getMultiAdapter((event, self.request), ISolgemaFullcalendarEventDict)()
         return json.dumps(eventDict, sort_keys=True)
 
 class SolgemaFullcalendarDropView(BrowserView):
