@@ -93,7 +93,7 @@ def getCriteriaItems(context, request):
     listCriteria = topic.listCriteria()
     topicCriteria = listQueryTopicCriteria(topic)
     if topicCriteria:
-        selectedCriteria = request.cookies.get('sfqueryDisplay', topicCriteria[0].Field())
+        selectedCriteria = request.cookies.get('sfqueryDisplay', topic.REQUEST.cookies.get('sfqueryDisplay', topicCriteria[0].Field()))
         criteria = [a for a in listCriteria if a.Field() == selectedCriteria]
     else:
         criteria = listCriteria
@@ -281,7 +281,7 @@ class SolgemaFullcalendarJS(BrowserView):
 
     def getTargetFolder(self):
         target_folder = getattr(self.calendar, 'target_folder', None)
-        addContext = target_folder and self.portal.restrictedTraverse('/'+self.portal.id+target_folder) or aq_parent(aq_inner(self.context))
+        addContext = target_folder and self.portal.unrestrictedTraverse('/'+self.portal.id+target_folder) or aq_parent(aq_inner(self.context))
         return addContext.absolute_url()
 
     def getHeaderRight(self):
